@@ -4,9 +4,10 @@ use warnings;
 
 package Path::Tiny;
 # ABSTRACT: File path utility
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 # Dependencies
+use Config;
 use Exporter 5.57   (qw/import/);
 use File::Spec 3.40 ();
 use Carp ();
@@ -43,6 +44,8 @@ sub _check_UU {
     eval { require Unicode::UTF8; Unicode::UTF8->VERSION(0.58); 1 };
 }
 
+my $HAS_FLOCK = $Config{d_flock} || $Config{d_fcntl_can_lock} || $Config{d_lockf};
+
 # notions of "root" directories differ on Win32: \\server\dir\ or C:\ or \
 my $SLASH      = qr{[\\/]};
 my $NOTSLASH   = qr{[^\\/]};
@@ -366,7 +369,7 @@ sub filehandle {
     $binmode = "" unless defined $binmode;
 
     my ( $fh, $lock, $trunc );
-    if ( $args->{locked} ) {
+    if ( $HAS_FLOCK && $args->{locked} ) {
         require Fcntl;
         # truncating file modes shouldn't truncate until lock acquired
         if ( grep { $opentype eq $_ } qw( > +> ) ) {
@@ -541,6 +544,7 @@ sub move {
 }
 
 
+# map method names to corresponding open mode
 my %opens = (
     opena  => ">>",
     openr  => "<",
@@ -691,6 +695,7 @@ sub spew {
     my $args = ( @data && ref $data[0] eq 'HASH' ) ? shift @data : {};
     $args = _get_args( $args, qw/binmode/ );
     my $binmode = $args->{binmode};
+    # get default binmode from caller's lexical scope (see "perldoc open")
     $binmode = ( ( caller(0) )[10] || {} )->{'open>'} unless defined $binmode;
     my $temp = path( $self->[PATH] . $TID . $$ );
     my $fh = $temp->filehandle( { locked => 1 }, ">", $binmode );
@@ -784,7 +789,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -792,7 +797,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.044
+version 0.045
 
 =head1 SYNOPSIS
 
@@ -849,7 +854,7 @@ All paths are forced to have Unix-style forward slashes.  Stringifying
 the object gives you back the path (after some clean up).
 
 File input/output methods C<flock> handles before reading or writing,
-as appropriate.
+as appropriate (if supported by the platform).
 
 The C<*_utf8> methods (C<slurp_utf8>, C<lines_utf8>, etc.) operate in raw
 mode without CRLF translation.  Installing L<Unicode::UTF8> 0.58 or later
@@ -1376,7 +1381,14 @@ Exception objects will stringify as the C<msg> field.
 
 =head1 CAVEATS
 
-=head2 NFS and BSD
+=head2 File locking
+
+If flock is not supported on a platform, it will not be used, even if
+locking is requested.
+
+See additional caveats below.
+
+=head3 NFS and BSD
 
 On BSD, Perl's flock implementation may not work to lock files on an
 NFS filesystem.  Path::Tiny has some heuristics to detect this
@@ -1386,7 +1398,7 @@ category:
 
     use warnings FATAL => 'flock';
 
-=head2 AIX and locking
+=head3 AIX and locking
 
 AIX requires a write handle for locking.  Therefore, calls that normally
 open a read handle and take a shared lock instead will open a read-write
@@ -1547,6 +1559,10 @@ Michael G. Schwern <mschwern@cpan.org>
 
 Toby Inkster <tobyink@cpan.org>
 
+=item *
+
+김도형 - Keedi Kim <keedi@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
